@@ -349,39 +349,51 @@ class SimpackGrokker(object, metaclass=caching.CachedType):
         
         step_function = step_profile.step_function
         step_type = StepType.get_step_type(step_function)
-        step_iterator_class = step_type.step_iterator_class
-
-        return step_iterator_class(state_or_history_browser,
-                                   step_profile)
+        
+        return step_type.step_iterator_class(state_or_history_browser,
+                                             step_profile)
         
     
     def get_inplace_step_iterator(self, state, step_profile):
         '''
-        Get an inplace step iterator which modifies the state in-place.
+        Get an inplace step iterator which modifies the state in place.
         
-        Not yet implemented, sorry.
+        On every iteration of the inplace step iterator, `state` will be
+        changed to be the next moment in the simulation. No new state objects
+        will be created.
+        
+        This can only be used with inplace step functions.
         '''
-        raise NotImplementedError('Inplace steps are not yet '
-                                  'supported. They will probably become '
-                                  'available in GarlicSim 0.7 in mid-2011.')
-        #step_function = step_profile.step_function
-        #step_type = StepType.get_step_type(step_function)
         
-        #if step_type not in (step_types.InplaceStep,
-                             #step_types.InplaceStepGenerator):
-
-            #raise GarlicSimException("Can't get inplace step iterator for "
-                                     #"`%s`, which is a non-inplace step "
-                                     #"function." % step_function)
-            
-        #inplace_step_iterator_class = step_type.inplace_step_iterator_class
-
-        #inplace_step_iterator = inplace_step_iterator_class(
-            #state_or_history_browser,
-            #step_profile
-        #)
+        step_function = step_profile.step_function
+        step_type = StepType.get_step_type(step_function)
+        
+        if step_type not in (step_types.InplaceStep,
+                             step_types.InplaceStepGenerator):
+            raise Exception("Can't get an inplace step iterator for the step "
+                            "function you're using, because it's not an "
+                            "inplace step function, it's a %s." % 
+                            step_type.verbose_name)
+        
+        return step_type.inplace_step_iterator_class(
+            state,
+            step_profile
+        )
+    
+    
+    def is_inplace_iterator_available(self, step_profile):
+        '''
+        Return whether `step_profile` allows using an inplace step iterator.
+        
+        Only step profiles that use an inplace step function (or generator)
+        allow using inplace step iterators.
+        '''
+        step_function = step_profile.step_function
+        step_type = StepType.get_step_type(step_function)
+        
+        return (step_type in (step_types.InplaceStep,
+                              step_types.InplaceStepGenerator))
         
-        #return inplace_step_iterator
     
 
     def build_step_profile(self, *args, **kwargs):
